@@ -377,11 +377,10 @@ decode_reply (GString *buffer, GVfsDaemonSocketProtocolReply *reply_out)
 static void
 decode_error (GVfsDaemonSocketProtocolReply *reply, char *data, GError **error)
 {
-  g_set_error (error,
-	       g_quark_from_string (data),
-	       reply->arg1,
-               "%s",
-               data + strlen (data) + 1);
+  g_set_error_literal (error,
+		       g_quark_from_string (data),
+		       reply->arg1,
+        	       data + strlen (data) + 1);
 }
 
 
@@ -513,10 +512,10 @@ iterate_read_state_machine (GDaemonFileInputStream *file, IOOperationData *io_op
 	  if (io_op->io_cancelled)
 	    {
 	      op->ret_val = -1;
-	      g_set_error (&op->ret_error,
-			   G_IO_ERROR,
-			   G_IO_ERROR_CANCELLED,
-			   "%s", _("Operation was cancelled"));
+	      g_set_error_literal (&op->ret_error,
+				   G_IO_ERROR,
+				   G_IO_ERROR_CANCELLED,
+				   _("Operation was cancelled"));
 	      return STATE_OP_DONE;
 	    }
 	  
@@ -669,11 +668,10 @@ iterate_read_state_machine (GDaemonFileInputStream *file, IOOperationData *io_op
 	  if (io_op->io_cancelled)
 	    {
 	      op->ret_val = -1;
-	      g_set_error (&op->ret_error,
-			   G_IO_ERROR,
-			   G_IO_ERROR_CANCELLED,
-                           "%s",
-			   _("Operation was cancelled"));
+	      g_set_error_literal (&op->ret_error,
+				   G_IO_ERROR,
+				   G_IO_ERROR_CANCELLED,
+				   _("Operation was cancelled"));
 	      return STATE_OP_DONE;
 	    }
 	  
@@ -743,10 +741,11 @@ g_daemon_file_input_stream_skip (GInputStream *stream,
 				 GCancellable *cancellable,
 				 GError      **error)
 {
+#if 0
   GDaemonFileInputStream *file;
 
   file = G_DAEMON_FILE_INPUT_STREAM (stream);
-  
+#endif  
   /* TODO: implement skip */
   g_assert_not_reached ();
   
@@ -777,11 +776,10 @@ iterate_close_state_machine (GDaemonFileInputStream *file, IOOperationData *io_o
 	  if (io_op->io_cancelled)
 	    {
 	      op->ret_val = FALSE;
-	      g_set_error (&op->ret_error,
-			   G_IO_ERROR,
-			   G_IO_ERROR_CANCELLED,
-                           "%s",
-			   _("Operation was cancelled"));
+	      g_set_error_literal (&op->ret_error,
+				   G_IO_ERROR,
+				   G_IO_ERROR_CANCELLED,
+				   _("Operation was cancelled"));
 	      return STATE_OP_DONE;
 	    }
 
@@ -1028,11 +1026,10 @@ iterate_seek_state_machine (GDaemonFileInputStream *file, IOOperationData *io_op
 	  if (io_op->io_cancelled)
 	    {
 	      op->ret_val = -1;
-	      g_set_error (&op->ret_error,
-			   G_IO_ERROR,
-			   G_IO_ERROR_CANCELLED,
-                           "%s",
-			   _("Operation was cancelled"));
+	      g_set_error_literal (&op->ret_error,
+				   G_IO_ERROR,
+				   G_IO_ERROR_CANCELLED,
+				   _("Operation was cancelled"));
 	      return STATE_OP_DONE;
 	    }
 
@@ -1206,8 +1203,8 @@ g_daemon_file_input_stream_seek (GFileInputStream *stream,
 
   if (!file->can_seek)
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
-		   "%s", _("Seek not supported on stream"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+			   _("Seek not supported on stream"));
       return FALSE;
     }
   
@@ -1237,11 +1234,7 @@ g_daemon_file_input_stream_query_info (GFileInputStream     *stream,
 				       GCancellable         *cancellable,
 				       GError              **error)
 {
-  GDaemonFileInputStream *file;
-
-  file = G_DAEMON_FILE_INPUT_STREAM (stream);
-
-  g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, "%s", _("The query info operation is not supported"));
+  g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("The query info operation is not supported"));
   
   return NULL;
 }
@@ -1502,7 +1495,6 @@ g_daemon_file_input_stream_read_async  (GInputStream        *stream,
 					gpointer            user_data)
 {
   GDaemonFileInputStream *file;
-  AsyncIterator *iterator;
   ReadOperation *op;
 
   file = G_DAEMON_FILE_INPUT_STREAM (stream);
@@ -1516,8 +1508,6 @@ g_daemon_file_input_stream_read_async  (GInputStream        *stream,
   op->buffer = buffer;
   op->buffer_size = count;
 
-  iterator = g_new0 (AsyncIterator, 1);
-  
   run_async_state_machine (file,
 			   (state_machine_iterator)iterate_read_state_machine,
 			   op,
@@ -1628,7 +1618,6 @@ g_daemon_file_input_stream_close_async (GInputStream       *stream,
 					gpointer            data)
 {
   GDaemonFileInputStream *file;
-  AsyncIterator *iterator;
   CloseOperation *op;
 
   file = G_DAEMON_FILE_INPUT_STREAM (stream);
@@ -1636,8 +1625,6 @@ g_daemon_file_input_stream_close_async (GInputStream       *stream,
   op = g_new0 (CloseOperation, 1);
   op->state = CLOSE_STATE_INIT;
 
-  iterator = g_new0 (AsyncIterator, 1);
-  
   run_async_state_machine (file,
 			   (state_machine_iterator)iterate_close_state_machine,
 			   op, io_priority,
