@@ -1,5 +1,3 @@
-/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
-
 /* GVFS cdrom audio file system driver
  * 
  * Copyright (C) 2007 Red Hat, Inc.
@@ -49,9 +47,6 @@
 #include "gvfsjobqueryinfo.h"
 #include "gvfsjobenumerate.h"
 
-/* see this bug http://bugzilla.gnome.org/show_bug.cgi?id=518284 */
-#define _I18N_LATER(x) x
-
 #define DO_NOT_WANT_PARANOIA_COMPATIBILITY
 #include <cdio/paranoia.h>
 
@@ -187,10 +182,12 @@ g_vfs_backend_cdda_init (GVfsBackendCdda *cdda_backend)
 {
   GVfsBackend *backend = G_VFS_BACKEND (cdda_backend);
   GMountSpec *mount_spec;
+  char *x_content_types[] = {"x-content/audio-cdda", NULL};
 
   //g_warning ("initing %p", cdda_backend);
 
   g_vfs_backend_set_display_name (backend, "cdda");
+  g_vfs_backend_set_x_content_types (backend, x_content_types);
   // TODO: HMM: g_vfs_backend_set_user_visible (backend, FALSE);  
 
   mount_spec = g_mount_spec_new ("cdda");
@@ -223,7 +220,7 @@ do_mount (GVfsBackend *backend,
     {
       release_device (cdda_backend);
       dbus_error_free (&dbus_error);
-      g_set_error (&error, G_IO_ERROR, G_IO_ERROR_FAILED, _I18N_LATER("Cannot connect to the system bus"));
+      g_set_error_literal (&error, G_IO_ERROR, G_IO_ERROR_FAILED, _("Cannot connect to the system bus"));
       g_vfs_job_failed_from_error (G_VFS_JOB (job), error);
       g_error_free (error);
       return;
@@ -233,7 +230,7 @@ do_mount (GVfsBackend *backend,
   if (cdda_backend->hal_ctx == NULL)
     {
       release_device (cdda_backend);
-      g_set_error (&error, G_IO_ERROR, G_IO_ERROR_FAILED, _I18N_LATER("Cannot create libhal context"));
+      g_set_error_literal (&error, G_IO_ERROR, G_IO_ERROR_FAILED, _("Cannot create libhal context"));
       g_vfs_job_failed_from_error (G_VFS_JOB (job), error);
       g_error_free (error);
       return;
@@ -246,7 +243,7 @@ do_mount (GVfsBackend *backend,
     {
       release_device (cdda_backend);
       dbus_error_free (&dbus_error);
-      g_set_error (&error, G_IO_ERROR, G_IO_ERROR_FAILED, _I18N_LATER("Cannot initialize libhal"));
+      g_set_error_literal (&error, G_IO_ERROR, G_IO_ERROR_FAILED, _("Cannot initialize libhal"));
       g_vfs_job_failed_from_error (G_VFS_JOB (job), error);
       g_error_free (error);
       return;
@@ -261,7 +258,7 @@ do_mount (GVfsBackend *backend,
   //g_warning ("host=%s", host);
   if (host == NULL)
     {
-      g_set_error (&error, G_IO_ERROR, G_IO_ERROR_FAILED, "%s", _("No drive specified"));
+      g_set_error_literal (&error, G_IO_ERROR, G_IO_ERROR_FAILED, _("No drive specified"));
       g_vfs_job_failed_from_error (G_VFS_JOB (job), error);
       g_error_free (error);
       release_device (cdda_backend);
@@ -285,7 +282,6 @@ do_mount (GVfsBackend *backend,
 
   if (cdio_cddap_open (cdda_backend->drive) != 0)
     {
-      cdio_cddap_close (cdda_backend->drive);
       g_set_error (&error, G_IO_ERROR, G_IO_ERROR_FAILED, 
                    _("Drive %s does not contain audio files"), cdda_backend->device_path);
       g_vfs_job_failed_from_error (G_VFS_JOB (job), error);
@@ -333,7 +329,7 @@ try_mount (GVfsBackend *backend,
   //g_warning ("tm host=%s", host);
   if (host == NULL)
     {
-      g_set_error (&error, G_IO_ERROR, G_IO_ERROR_FAILED, "%s", _("No drive specified"));
+      g_set_error_literal (&error, G_IO_ERROR, G_IO_ERROR_FAILED, _("No drive specified"));
       g_vfs_job_failed_from_error (G_VFS_JOB (job), error);
       g_error_free (error);
       return TRUE;
@@ -823,7 +819,7 @@ do_query_info (GVfsBackend *backend,
 
       if (track_num > cdda_backend->drive->tracks)
         {
-          error = g_error_new (G_IO_ERROR, G_IO_ERROR_NOT_FOUND, _("The file does not exist"));
+          error = g_error_new (G_IO_ERROR, G_IO_ERROR_NOT_FOUND, _("File doesn't exist"));
           g_vfs_job_failed_from_error (G_VFS_JOB (job), error);
           return;
         }
@@ -932,3 +928,9 @@ g_vfs_backend_cdda_class_init (GVfsBackendCddaClass *klass)
   backend_class->query_fs_info = do_query_fs_info;
   backend_class->enumerate = do_enumerate;
 }
+
+void
+g_vfs_cdda_daemon_init (void)
+{
+  g_set_application_name (_("Audio CD Filesystem Service"));
+}
